@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_stepfunctions._jsii
@@ -16,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-stepfunctions-patterns",
-    "0.1.3",
+    "0.1.5",
     __name__[0:-6],
-    "cdk-stepfunctions-patterns@0.1.3.jsii.tgz",
+    "cdk-stepfunctions-patterns@0.1.5.jsii.tgz",
 )
 
 __all__ = [
